@@ -3,20 +3,18 @@
  *
  * Copyright (C) 2011 Kaj-Michael Lang
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ *  gdspeak is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ *  gdspeak is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU Lesser Public License
+ *  along with gdspeak.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -45,7 +43,6 @@
 
 #include "gdspeak-marshal.h"
 #include "gdspeak-server-glue.h"
-
 #define DEFAULT_VOICE "en"
 
 #define PITCH_MIN (0)
@@ -139,6 +136,8 @@ typedef struct _GdspeakPrivate GdspeakPrivate;
 struct _GdspeakPrivate {
 	GQueue *sentences;
 	GHashTable *voices;
+	GHashTable *current;
+	gchar *dvoice;
 	Sentence *cs;
 #ifdef WITH_GST
 	GstEspeak ge;
@@ -304,8 +303,8 @@ gst_app_src_set_size(GST_APP_SRC(p->ge.src), -1);
 gst_app_src_set_stream_type(GST_APP_SRC(p->ge.src), GST_APP_STREAM_TYPE_STREAM);
 g_object_set(GST_APP_SRC(p->ge.src), "block", TRUE, NULL);
 g_object_set(GST_APP_SRC(p->ge.src), "is-live", TRUE, NULL);
-gst_app_src_set_size(p->ge.src, -1);
-gst_app_src_set_max_bytes(p->ge.src, 2048);
+gst_app_src_set_size(GST_APP_SRC(p->ge.src), -1);
+gst_app_src_set_max_bytes(GST_APP_SRC(p->ge.src), 2048);
 #endif
 
 p->ge.srccaps=gst_caps_new_simple("audio/x-raw-int",
@@ -518,6 +517,7 @@ G_OBJECT_CLASS(gdspeak_parent_class)->finalize(object);
 
 p=GET_PRIVATE(gs);
 g_hash_table_destroy(p->voices);
+g_hash_table_destroy(p->current);
 #ifdef WITH_GST
 gst_espeak_destroy_pipeline(p);
 #endif
@@ -667,6 +667,7 @@ p=GET_PRIVATE(gs);
 
 p->sentences=g_queue_new();
 p->id=1;
+p->dvoice=g_strdup(DEFAULT_VOICE);
 
 #ifdef WITH_GST
 #if 1
@@ -688,12 +689,13 @@ p->sp.pitch=50;
 p->sp.range=50;
 p->sp.rate=espeakRATE_NORMAL;
 p->sp.volume=50;
-p->sp.lang=g_strdup(DEFAULT_VOICE);
+p->sp.lang=g_strdup(p->dvoice);
 
 espeak_set_properties(&p->sp);
 
 vs=espeak_ListVoices(NULL);
 p->voices=g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
+p->current=g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
 
 for (i=(espeak_VOICE **)vs; *i; i++) {
 	espeak_VOICE *v=*i;
@@ -718,6 +720,11 @@ gdspeak_new(void)
 return g_object_new(GDSPEAK_TYPE, NULL);
 }
 
+/**
+ * gdspeak_list_voices:
+ *
+ * Get a list of voices available.
+ */
 GHashTable *
 gdspeak_list_voices(Gdspeak *gs)
 {
@@ -726,6 +733,14 @@ GdspeakPrivate *p=GET_PRIVATE(gs);
 return p->voices;
 }
 
+guint
+gdspeak_voices(Gdspeak *gs)
+{
+GdspeakPrivate *p=GET_PRIVATE(gs);
+
+return g_hash_table_size(p->voices);
+}
+
 static gboolean
 gdspeak_push_sentence(GdspeakPrivate *p, Sentence *s)
 {
@@ -814,13 +829,13 @@ if (G_UNLIKELY(p->id==0))
 	p->id=1;
 
 s=sentence_new(p->id++, txt);
-s->priority=CLAMP(priority,0,255);
+s->priority=CLAMP((gint)priority,0,255);
 
 s->sp.lang=NULL;
 if (lang && g_hash_table_lookup(p->voices, lang)!=NULL)
 	s->sp.lang=g_strdup(lang);
-else if (lang && lang[0]!=0)
-	g_warning("No such language: [%s]", lang);
+else
+	s->sp.lang=g_strdup(p->dvoice);
 s->sp.pitch=pitch>-1 ? CLAMP(pitch, PITCH_MIN, PITCH_MAX) : -1;
 s->sp.range=range>-1 ? CLAMP(range, RANGE_MIN, RANGE_MAX) : -1;
 s->sp.rate=rate>-1 ? CLAMP(rate, espeakRATE_MINIMUM, espeakRATE_MAXIMUM) : -1;
@@ -897,7 +912,9 @@ g_queue_foreach(p->sentences, (GFunc)sentence_free, NULL);
 /**
  * gdspeak_stop:
  *
+ * Stop speech output, with optional queue clear.
  *
+ * Returns: TRUE if speech output was stopped. FALSE otherwise.
  */
 gboolean
 gdspeak_stop(Gdspeak *gs, gboolean clear)
@@ -921,7 +938,9 @@ return espeak_Cancel()==EE_OK ? TRUE : FALSE;
 /**
  * gdspeak_speaking:
  *
+ * Check if we are speaking a sentence.
  *
+ * Returns: TRUE if a sentence is being played, FALSE if not.
  */
 gboolean
 gdspeak_speaking(Gdspeak *gs)
@@ -955,7 +974,63 @@ return espeak_IsPlaying()==1 ? TRUE : FALSE;
 gboolean
 gdspeak_set_voice(Gdspeak *gs, const gchar *voice)
 {
+GdspeakPrivate *p;
+
 g_return_val_if_fail(gs, FALSE);
 
+p=GET_PRIVATE(gs);
 return espeak_SetVoiceByName(voice)==EE_OK ? TRUE : FALSE;
 }
+
+/**
+ * gdspeak_set_default_voice:
+ *
+ * Set the default voice to use if nothing else is specified.
+ *
+ * Returns: TRUE if voice was available and set, FALSE if voice was not found.
+ */
+gboolean
+gdspeak_set_default_voice(Gdspeak *gs, const gchar *voice)
+{
+GdspeakPrivate *p;
+
+g_return_val_if_fail(gs, FALSE);
+
+p=GET_PRIVATE(gs);
+
+if (g_hash_table_lookup_extended(p->voices, voice, NULL, NULL)==FALSE)
+	return FALSE;
+
+g_free(p->dvoice);
+p->dvoice=g_strdup(voice);
+return TRUE;
+}
+
+/**
+ * gdspeak_get_voice:
+ *
+ * Get the current voice.
+ *
+ * Returns: The current voice id.
+ */
+GHashTable *
+gdspeak_get_voice(Gdspeak *gs)
+{
+espeak_VOICE *cv;
+GdspeakPrivate *p;
+
+g_return_val_if_fail(gs, FALSE);
+
+p=GET_PRIVATE(gs);
+
+cv=espeak_GetCurrentVoice();
+
+g_hash_table_insert(p->current, g_strdup("name"), g_strdup(cv->name));
+g_hash_table_insert(p->current, g_strdup("languages"), g_strdup(cv->languages));
+g_hash_table_insert(p->current, g_strdup("identifier"), g_strdup(cv->identifier));
+g_hash_table_insert(p->current, g_strdup("gender"), g_strdup_printf("%d", cv->gender ));
+g_hash_table_insert(p->current, g_strdup("age"), g_strdup_printf("%d", cv->age));
+
+return p->current;
+}
+
