@@ -3,20 +3,18 @@
  *
  * Copyright (C) 2011 Kaj-Michael Lang
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ *  gdspeak is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ *  gdspeak is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU Lesser Public License
+ *  along with gdspeak.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -64,7 +62,10 @@ void gdspeak_clear(Gdspeak *gs);
 gboolean gdspeak_speaking(Gdspeak *gds);
 
 gboolean gdspeak_set_voice(Gdspeak *gs, const gchar *voice);
+gboolean gdspeak_set_default_voice(Gdspeak *gs, const gchar *voice);
+GHashTable *gdspeak_get_voice(Gdspeak *gs);
 
+guint gdspeak_voices(Gdspeak *gs);
 GHashTable *gdspeak_list_voices(Gdspeak *gs);
 
 G_END_DECLS
